@@ -148,7 +148,9 @@ class K8sScheduler(Scheduler, ConfigurableClass):
 
         existing_cron_job = self.get_cron_job(schedule_origin_id=schedule_origin_id)
         if existing_cron_job:
-            self._api.patch_namespaced_cron_job(
+            # patch_namespaced_cron_job will cause the containers array to be additive
+            # https://blog.atomist.com/kubernetes-apply-replace-patch/
+            self._api.replace_namespaced_cron_job(
                 name=schedule_origin_id, body=cron_job, namespace=self._namespace
             )
         else:
@@ -180,7 +182,7 @@ class K8sScheduler(Scheduler, ConfigurableClass):
 
         self.start_schedule(instance, external_schedule)
 
-    def running_schedule_count(self, schedule_origin_id):
+    def running_schedule_count(self, instance, schedule_origin_id):
         check.str_param(schedule_origin_id, "schedule_origin_id")
 
         if self.get_cron_job(schedule_origin_id):
